AppstraxAuth class

Constructors

AppstraxAuth()
factory

Properties

config Config
final
hashCode int
The hash code for this object.
no setterinherited
http HttpService
final
loading bool
getter/setter pair
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
tokens Tokens?
getter/setter pair

Methods

changePassword(ChangePasswordDto changePasswordDto) Future<User>
disableTwoFactorAuthentication() Future<User>
enableTwoFactorAuth(String code) Future<User>
forgotPassword(ForgotPasswordDto forgotDto) Future<Message>
generateTwoFactorAuthSecret() Future<Map<String, String>>
getAuthStatus() Future<String>
getAuthToken() Future<Tokens?>
getAuthUrl(String extension) String
getUser() Future<User?>
getUserId() Future<String?>
initialize() Future<void>
isAuthenticated() Future<bool>
login(LoginDto loginDto) Future<AuthResult>
logout() Future<void>
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
onAuthStateChanged(Tokens? tokens) Future<void>
register(RegisterDto registerDto) Future<AuthResult>
resetPassword(ResetPasswordDto resetDto) Future<Message>
saveUserData(Map<String, dynamic> data) Future<User>
sendEmailVerificationCode() Future<void>
toString() String
A string representation of this object.
inherited
validateTokens() Future<void>
verifyEmailAddress(String code) Future<User>
verifyTwoFactorAuthCode(String code) Future<User>

Operators

operator ==(Object other) bool
The equality operator.
inherited