FindResultDto<T extends DocumentDto> class
Constructors
-
FindResultDto({List<
DocumentDto> ? data, dynamic where, dynamic order, int? limit, int? offset, int? count}) -
FindResultDto.fromJson(Map<
String, dynamic> json) -
factory
Properties
- count ↔ int?
-
getter/setter pair
-
data
↔ List<
DocumentDto> ? -
getter/setter pair
- hashCode → int
-
The hash code for this object.
no setterinherited
- limit ↔ int?
-
getter/setter pair
- offset ↔ int?
-
getter/setter pair
- order ↔ dynamic
-
getter/setter pair
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
- where ↔ dynamic
-
getter/setter pair
Methods
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toJson(
) → Map< String, dynamic> -
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited