AppstraxStorage class

Constructors

AppstraxStorage()
factory

Properties

config Config
final
hashCode int
The hash code for this object.
no setterinherited
http HttpService
final
runtimeType Type
A representation of the runtime type of the object.
no setterinherited

Methods

deleteFile(String downloadUrl) Future<void>
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() String
A string representation of this object.
inherited
uploadFile(File file, String folder, {HttpOptions? options}) Future<Response>

Operators

operator ==(Object other) bool
The equality operator.
inherited